@@ -366,6 +366,8 @@ module GObjectIntrospection
     end
 
     def match_argument?(arg_info, argument)
+      return true if argument.nil? and arg_info.may_be_null?
+
       type = arg_info.type
       case type.tag
       when TypeTag::BOOLEAN
@@ -437,6 +439,12 @@ module GObjectIntrospection
       if name == "initialize"
         name += "_raw"
       end
+
+      n_in_args = function_info.n_in_args
+      if options[:n_in_args_offset]
+        n_in_args += options[:n_in_args_offset]
+      end
+
       return_type = function_info.return_type
       return_type_tag = return_type.tag
       if return_type_tag == TypeTag::VOID
@@ -445,11 +453,12 @@ module GObjectIntrospection
           return_type_tag = TypeTag::ARRAY
         end
       end
+
       case return_type_tag
       when TypeTag::BOOLEAN
         case name
         when "equal"
-          if function_info.n_in_args == 1
+          if n_in_args == 1
             "=="
           else
             name
@@ -457,7 +466,7 @@ module GObjectIntrospection
         when /\A(?:is|get_is|can_be)_/
           "#{$POSTMATCH}?"
         when /\Aget_/
-          if function_info.n_in_args.zero?
+          if n_in_args.zero?
             if function_info.n_out_args.zero?
               "#{$POSTMATCH}?"
             else
@@ -476,7 +485,7 @@ module GObjectIntrospection
       when TypeTag::GLIST, TypeTag::GSLIST, TypeTag::ARRAY
         case name
         when /\A(?:list|get)_/
-          if function_info.n_in_args.zero?
+          if n_in_args.zero?
             $POSTMATCH
           else
             name
@@ -487,13 +496,15 @@ module GObjectIntrospection
       else
         case name
         when /\Aget_/
-          if function_info.n_in_args.zero?
+          if n_in_args.zero?
             $POSTMATCH
           else
             name
           end
         when "to_string"
           "to_s"
+        when "to_integer"
+          "to_i"
         when "foreach"
           "each"
         else
